@@ -394,13 +394,12 @@ SDL_Surface* MLV_get_image_data( MLV_Image* image ){
 	return image->surface;
 }
 
-void get_pixel_on_image( 
+
+void get_pixel_on_image_unsafe( 
 	SDL_Surface* surface,
 	int x, int y,
 	int* red, int* green, int* blue, int* alpha
 ){
-	SDL_LockSurface(surface);
-
 	/* Extracting color components from a 32-bit color value */
 	SDL_PixelFormat *fmt;
 	Uint32 temp, pixel;
@@ -439,6 +438,20 @@ void get_pixel_on_image(
 		temp = temp << fmt->Aloss;  /* Expand to a full 8-bit number */
 		*alpha = temp;
 	}
+}
+
+void get_pixel_on_image( 
+	SDL_Surface* surface,
+	int x, int y,
+	int* red, int* green, int* blue, int* alpha
+){
+	SDL_LockSurface(surface);
+
+	get_pixel_on_image_unsafe( 
+		surface,
+		x, y,
+		red, green, blue, alpha
+	);
 	
 	SDL_UnlockSurface(surface);
 }
@@ -494,3 +507,15 @@ void MLV_draw_partial_image_on_image(
 	);
 }
 
+///////////////////////////////////////////////////////////////////////////////
+// Save screen                                                               //
+///////////////////////////////////////////////////////////////////////////////
+
+void MLV_save_screen(){
+    SDL_BlitSurface( MLV_data->screen, NULL, MLV_data->save_screen, &(MLV_data->rectangle));
+}
+
+void MLV_load_screen(){
+    SDL_BlitSurface( MLV_data->save_screen, NULL, MLV_data->screen, &(MLV_data->rectangle));
+}
+
