@@ -18,6 +18,20 @@
  *    along with this Library.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <stdio.h>
+
+#include "platform.h"
+
+#ifdef OS_WINDOWS
+/* Get va_list.  */
+#if __STDC__ || defined __cplusplus || defined _MSC_VER
+# include <stdarg.h>
+#else
+# include <varargs.h>
+#endif
+extern int vasprintf (char **, const char *, va_list);
+#endif
+
 #include "MLV_input_box.h"
 #include "MLV_event.h"
 #include "MLV_text.h"
@@ -118,7 +132,10 @@ struct _MLV_Input_box {
  *
  *
  * */
-inline void recalculateTextPositions_NTS( MLV_Input_box* input_box ){
+#ifndef OS_APPLE  // Hack to compile with MAC OS 10.9 (maverick)
+inline
+#endif
+void recalculateTextPositions_NTS( MLV_Input_box* input_box ){
 	int width_message, height_message;
 	MLV_get_size_of_text_with_font(
 		input_box->informativeMessage,
@@ -196,7 +213,10 @@ new
                         |
                       curseur
  */
-inline void add_carac_input_box_NTS( MLV_Input_box* input_box, char c ){
+#ifndef OS_APPLE  // Hack to compile with MAC OS 10.9 (maverick)
+inline
+#endif
+void add_carac_input_box_NTS( MLV_Input_box* input_box, char c ){
     int l = strlen(input_box->history->data);
     int m = input_box->positionCursor ;
 //	DEBUG("Add History Entry");
@@ -228,7 +248,10 @@ resultat
                     |
                  curseur
  */
-inline void suppress_carac_input_box_NTS( MLV_Input_box* input_box ){
+#ifndef OS_APPLE  // Hack to compile with MAC OS 10.9 (maverick)
+inline
+#endif
+void suppress_carac_input_box_NTS( MLV_Input_box* input_box ){
     int l = strlen(input_box->history->data);
     int m = input_box->positionCursor ;
     if( l == m ) return;
@@ -252,7 +275,10 @@ resulat
                 |
               curseur
  */
-inline void return_deletion_carac_input_box_NTS( MLV_Input_box* input_box ){
+#ifndef OS_APPLE  // Hack to compile with MAC OS 10.9 (maverick)
+inline
+#endif
+void return_deletion_carac_input_box_NTS( MLV_Input_box* input_box ){
     int l = strlen(input_box->history->data);
     int m = input_box->positionCursor ;
     if( m != 0 ){
@@ -262,12 +288,18 @@ inline void return_deletion_carac_input_box_NTS( MLV_Input_box* input_box ){
 }
 
 
-inline void recalculateSommetBas_NTS( MLV_Input_box* input_box ){
+#ifndef OS_APPLE  // Hack to compile with MAC OS 10.9 (maverick)
+inline
+#endif
+void recalculateSommetBas_NTS( MLV_Input_box* input_box ){
     input_box->sommetBasDroit[0] = input_box->sommetHautGauche[0] + input_box->width;
     input_box->sommetBasDroit[1] = input_box->sommetHautGauche[1] + input_box->height;
 }
 
-inline void change_position_input_box_NTS(MLV_Input_box* input_box, int sommetHautGaucheX, int sommetHautGaucheY){
+#ifndef OS_APPLE  // Hack to compile with MAC OS 10.9 (maverick)
+inline
+#endif
+void change_position_input_box_NTS(MLV_Input_box* input_box, int sommetHautGaucheX, int sommetHautGaucheY){
     input_box->sommetHautGauche[0] = sommetHautGaucheX;
     input_box->sommetHautGauche[1] = sommetHautGaucheY;
     input_box->rectangle.x = sommetHautGaucheX;
@@ -282,7 +314,10 @@ void MLV_change_position_input_box(MLV_Input_box* input_box, int sommetHautGauch
     unlock_input_box( input_box );
 }
 
-inline void change_size_input_box_NTS(MLV_Input_box* input_box, int width, int height){
+#ifndef OS_APPLE  // Hack to compile with MAC OS 10.9 (maverick)
+inline
+#endif
+void change_size_input_box_NTS(MLV_Input_box* input_box, int width, int height){
     if( (width < 0) || (height < 0)){
 		ERROR_FULL( "Les tailles ne sont pas correctes." );
     }
@@ -306,7 +341,10 @@ void MLV_change_input_box_size(MLV_Input_box* input_box, int width, int height){
     unlock_input_box( input_box );
 }
 
-inline void change_geometry_input_box_NTS(MLV_Input_box* input_box,  int sommetHautGaucheX, int sommetHautGaucheY, int width, int height){
+#ifndef OS_APPLE  // Hack to compile with MAC OS 10.9 (maverick)
+inline
+#endif
+void change_geometry_input_box_NTS(MLV_Input_box* input_box,  int sommetHautGaucheX, int sommetHautGaucheY, int width, int height){
     change_size_input_box_NTS( input_box, width, height );
     change_position_input_box_NTS( input_box, sommetHautGaucheX, sommetHautGaucheY);
 };
@@ -317,19 +355,28 @@ void MLV_change_input_box_geometry(MLV_Input_box* input_box,  int sommetHautGauc
     unlock_input_box( input_box );
 };
 
-inline void change_colors_input_box_NTS( MLV_Input_box* input_box,  MLV_Color borderColor, MLV_Color textColor, MLV_Color backgroundColor ){
+#ifndef OS_APPLE  // Hack to compile with MAC OS 10.9 (maverick)
+inline
+#endif
+void change_colors_input_box_NTS( MLV_Input_box* input_box,  MLV_Color borderColor, MLV_Color textColor, MLV_Color backgroundColor ){
     input_box->borderColor = borderColor;
     input_box->textColor = textColor;
     input_box->backgroundColor = backgroundColor;
 };
 
-inline void MLV_change_input_box_colors( MLV_Input_box* input_box,  MLV_Color borderColor, MLV_Color textColor, MLV_Color backgroundColor ){
+#ifndef OS_APPLE  // Hack to compile with MAC OS 10.9 (maverick)
+inline
+#endif
+void MLV_change_input_box_colors( MLV_Input_box* input_box,  MLV_Color borderColor, MLV_Color textColor, MLV_Color backgroundColor ){
     lock_input_box( input_box );
     change_colors_input_box_NTS( input_box, borderColor, textColor, backgroundColor );
     unlock_input_box( input_box );
 }
 
-inline void desactivate_input_box_NTS( ){
+#ifndef OS_APPLE  // Hack to compile with MAC OS 10.9 (maverick)
+inline
+#endif
+void desactivate_input_box_NTS( ){
 	if( input_box_information.input_box_activated ){
 		input_box_information.input_box_activated->isListenning = 0;
 		input_box_information.input_box_activated = NULL;
@@ -342,7 +389,10 @@ void MLV_desactivate_input_box( ){
     unlock_input_box_information();
 }
 
-inline void  activate_imput_box_NTS( MLV_Input_box* input_box ){
+#ifndef OS_APPLE  // Hack to compile with MAC OS 10.9 (maverick)
+inline
+#endif
+void  activate_imput_box_NTS( MLV_Input_box* input_box ){
 	desactivate_input_box_NTS( );
 	input_box->isListenning = 1;
 	input_box_information.input_box_activated = input_box;
@@ -356,7 +406,10 @@ void MLV_activate_input_box( MLV_Input_box* input_box ){
     unlock_input_box_information();
 }
 
-inline int is_in_input_box_NTS( MLV_Input_box* input_box, int x, int y ){
+#ifndef OS_APPLE  // Hack to compile with MAC OS 10.9 (maverick)
+inline
+#endif
+int is_in_input_box_NTS( MLV_Input_box* input_box, int x, int y ){
     int result = 0;
     if( (x >= input_box->sommetHautGauche[0]) &&
         (x <= input_box->sommetBasDroit[0]) &&
@@ -366,7 +419,10 @@ inline int is_in_input_box_NTS( MLV_Input_box* input_box, int x, int y ){
     return result;
 }
 
-inline MLV_Input_box* is_in_an_input_box_NTS( int x, int y ){
+#ifndef OS_APPLE  // Hack to compile with MAC OS 10.9 (maverick)
+inline
+#endif
+MLV_Input_box* is_in_an_input_box_NTS( int x, int y ){
     MLV_Input_box* result = NULL;
     MLV_List* list = input_box_information.input_box_list;
     while( list ){
@@ -380,7 +436,10 @@ inline MLV_Input_box* is_in_an_input_box_NTS( int x, int y ){
     return result;
 }
 
-inline void construct_input_box_NTS( MLV_Input_box* input_box ){
+#ifndef OS_APPLE  // Hack to compile with MAC OS 10.9 (maverick)
+inline
+#endif
+void construct_input_box_NTS( MLV_Input_box* input_box ){
 	int width_message_before_input_box, height_message_before_input_box;
 
     boxColor(
@@ -461,16 +520,22 @@ inline void construct_input_box_NTS( MLV_Input_box* input_box ){
 	);
 }
 
-inline void input_box_register_NTS(MLV_Input_box* input_box){
+#ifndef OS_APPLE  // Hack to compile with MAC OS 10.9 (maverick)
+inline
+#endif
+void input_box_register_NTS(MLV_Input_box* input_box){
     input_box_information.input_box_list = MLV_prepend_list( input_box_information.input_box_list , input_box );
 }
 
-inline void input_box_unregister_NTS(MLV_Input_box* input_box){
+#ifndef OS_APPLE  // Hack to compile with MAC OS 10.9 (maverick)
+inline
+#endif
+void input_box_unregister_NTS(MLV_Input_box* input_box){
     if( input_box_information.input_box_activated == input_box ) desactivate_input_box_NTS();
     input_box_information.input_box_list = MLV_remove_list( input_box_information.input_box_list, input_box );
 }
 
-MLV_Input_box* MLV_create_input_box_with_font(
+MLV_Input_box* create_input_box_with_font(
 	int sommetHautGaucheX, int sommetHautGaucheY,
 	int width, int height,
 	MLV_Color borderColor, MLV_Color textColor,
@@ -512,29 +577,99 @@ MLV_Input_box* MLV_create_input_box_with_font(
     return input_box;
 }
 
-MLV_Input_box* MLV_create_input_box( 
+MLV_Input_box* MLV_create_input_box_with_font_va(
 	int sommetHautGaucheX, int sommetHautGaucheY,
 	int width, int height,
 	MLV_Color borderColor, MLV_Color textColor,
 	MLV_Color backgroundColor,
-	const char* informativeMessage
+	const char* informativeMessage,
+	const MLV_Font* font, va_list pile
 ){
-	return MLV_create_input_box_with_font(
+	char* complete_informative_message;
+	if(
+		vasprintf( 
+			&complete_informative_message, informativeMessage, pile 
+		)==-1 
+	){
+		ERROR("Unexpected Error.");
+	}
+	MLV_Input_box* result = create_input_box_with_font(
+		sommetHautGaucheX, sommetHautGaucheY, width, height, borderColor, 
+		textColor, backgroundColor, complete_informative_message, font
+	);
+	free( complete_informative_message );
+	return result;
+}
+
+MLV_Input_box* MLV_create_input_box_with_font(
+	int sommetHautGaucheX, int sommetHautGaucheY,
+	int width, int height,
+	MLV_Color borderColor, MLV_Color textColor,
+	MLV_Color backgroundColor,
+	const char* informativeMessage,
+	const MLV_Font* font, ...
+){
+	va_list pile;
+	va_start( pile, font );
+	MLV_Input_box* result = MLV_create_input_box_with_font_va(
 		sommetHautGaucheX, sommetHautGaucheY,
 		width, height,
 		borderColor, textColor,
 		backgroundColor,
 		informativeMessage,
-		MLV_data->defaultFont
+		font, pile
+	);
+	va_end( pile );
+	return result;
+}
+
+MLV_Input_box* MLV_create_input_box_va(
+	int sommetHautGaucheX, int sommetHautGaucheY,
+	int width, int height,
+	MLV_Color borderColor, MLV_Color textColor,
+	MLV_Color backgroundColor,
+	const char* informativeMessage,
+	va_list pile
+){
+	return MLV_create_input_box_with_font_va(
+		sommetHautGaucheX, sommetHautGaucheY,
+		width, height,
+		borderColor, textColor,
+		backgroundColor,
+		informativeMessage,
+		MLV_data->defaultFont, pile
 	);
 }
 
-inline void free_NTS( void* data, void* useless ){
+MLV_Input_box* MLV_create_input_box( 
+	int sommetHautGaucheX, int sommetHautGaucheY,
+	int width, int height,
+	MLV_Color borderColor, MLV_Color textColor,
+	MLV_Color backgroundColor,
+	const char* informativeMessage, ...
+){
+	va_list pile;
+	va_start( pile, informativeMessage );
+	MLV_Input_box* result = MLV_create_input_box_va( 
+		sommetHautGaucheX, sommetHautGaucheY,
+		width, height,
+		borderColor, textColor,
+		backgroundColor,
+		informativeMessage, pile
+	);
+	va_end( pile );
+	return result;
+}
+
+void free_NTS( void* data, void* useless ){
 //	DEBUG("Free Entry Hystory");
 	MLV_FREE( data, char );
 }
 
-inline void suppressHistory_NTS( MLV_Input_box* input_box ){
+#ifndef OS_APPLE  // Hack to compile with MAC OS 10.9 (maverick)
+inline
+#endif
+void suppressHistory_NTS( MLV_Input_box* input_box ){
     MLV_foreach_list( input_box->history, free_NTS, NULL );
 //	DEBUG("Free history");
     MLV_free_list( input_box->history );
@@ -565,7 +700,7 @@ void MLV_free_input_box( MLV_Input_box* input_box ){
 	MLV_FREE( input_box, MLV_Input_box );
 }
 
-void MLV_change_informative_message_of_input_box(
+void change_informative_message_of_input_box(
 	MLV_Input_box* input_box, const char* message
 ){
     lock_input_box(input_box);
@@ -580,6 +715,29 @@ void MLV_change_informative_message_of_input_box(
     unlock_input_box(input_box);
 }
 
+void MLV_change_informative_message_of_input_box_va(
+	MLV_Input_box* input_box, const char* message, va_list pile
+){
+	char* complete_message;
+	if( vasprintf( &complete_message, message, pile )==-1 ){
+		ERROR("Unexpected Error.");
+	}
+	change_informative_message_of_input_box(
+		input_box, complete_message
+	);
+	free( complete_message );
+}
+
+void MLV_change_informative_message_of_input_box(
+	MLV_Input_box* input_box, const char* message, ...
+){
+	va_list pile;
+	va_start( pile, message );
+	MLV_change_informative_message_of_input_box_va(
+		input_box, message, pile
+	);
+	va_end( pile );
+}
 
 void MLV_draw_input_box( MLV_Input_box* input_box ){
     lock_input_box( input_box );
@@ -607,7 +765,10 @@ void quit_input_box_mechanism(){
 	SDL_DestroySemaphore(input_box_information.semaphore);
 }
 
-inline void replaceEntreeByHistory_NTS( MLV_Input_box* input_box ){
+#ifndef OS_APPLE  // Hack to compile with MAC OS 10.9 (maverick)
+inline
+#endif
+void replaceEntreeByHistory_NTS( MLV_Input_box* input_box ){
     char* dst = input_box->history->data;
     if( input_box->positionHistory != input_box->history ){
         char* src = (char*) input_box->positionHistory->data;
@@ -628,7 +789,10 @@ inline void replaceEntreeByHistory_NTS( MLV_Input_box* input_box ){
     input_box->positionCursor = strlen(input_box->history->data);
 }
 
-inline void goDownInHistory_NTS( MLV_Input_box* input_box ){
+#ifndef OS_APPLE  // Hack to compile with MAC OS 10.9 (maverick)
+inline
+#endif
+void goDownInHistory_NTS( MLV_Input_box* input_box ){
     if( input_box->positionHistory->previous ){
         input_box->positionHistory = input_box->positionHistory->previous;
     }else{
@@ -637,7 +801,10 @@ inline void goDownInHistory_NTS( MLV_Input_box* input_box ){
     replaceEntreeByHistory_NTS( input_box );
 }
 
-inline void goUpInHistory_NTS( MLV_Input_box* input_box ){
+#ifndef OS_APPLE  // Hack to compile with MAC OS 10.9 (maverick)
+inline
+#endif
+void goUpInHistory_NTS( MLV_Input_box* input_box ){
     if( input_box->positionHistory->next ){
         input_box->positionHistory = input_box->positionHistory->next;
     }else{
@@ -646,24 +813,36 @@ inline void goUpInHistory_NTS( MLV_Input_box* input_box ){
     replaceEntreeByHistory_NTS( input_box );
 }
 
-inline void make_the_input_box_visible_NTS( MLV_Input_box* input_box ){
+#ifndef OS_APPLE  // Hack to compile with MAC OS 10.9 (maverick)
+inline
+#endif
+void make_the_input_box_visible_NTS( MLV_Input_box* input_box ){
     input_box->lastTime = SDL_GetTicks();
     input_box->cursorIsVisible = 1;
 }
 
-inline void input_box_move_left_answer_NTS( MLV_Input_box* input_box ){
+#ifndef OS_APPLE  // Hack to compile with MAC OS 10.9 (maverick)
+inline
+#endif
+void input_box_move_left_answer_NTS( MLV_Input_box* input_box ){
     if( input_box->positionCursor > 0 ){
         input_box->positionCursor--;
     }
 }
 
-inline void input_box_move_right_answer_NTS( MLV_Input_box* input_box ){
+#ifndef OS_APPLE  // Hack to compile with MAC OS 10.9 (maverick)
+inline
+#endif
+void input_box_move_right_answer_NTS( MLV_Input_box* input_box ){
     if( input_box->positionCursor < strlen( input_box->history->data ) ){
         input_box->positionCursor++;
     }
 }
 
-inline void validate_input_box_NTS( MLV_Input_box* input_box ){
+#ifndef OS_APPLE  // Hack to compile with MAC OS 10.9 (maverick)
+inline
+#endif
+void validate_input_box_NTS( MLV_Input_box* input_box ){
     SDL_Event event;
     event.type = SDL_USEREVENT;
 	event.user.code = MLV_INPUT_BOX;
