@@ -316,6 +316,391 @@ MLV_Keyboard_button MLV_convert_string_to_keyboard_button( const char* key_strin
 	if(strcmp(key_string,"MLV_KEYBOARD_DELETE") == 0){
 		return MLV_KEYBOARD_DELETE;
 	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_0") == 0){
+		return MLV_KEYBOARD_WORLD_0;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_1") == 0){
+		return MLV_KEYBOARD_WORLD_1;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_2") == 0){
+		return MLV_KEYBOARD_WORLD_2;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_3") == 0){
+		return MLV_KEYBOARD_WORLD_3;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_4") == 0){
+		return MLV_KEYBOARD_WORLD_4;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_5") == 0){
+		return MLV_KEYBOARD_WORLD_5;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_6") == 0){
+		return MLV_KEYBOARD_WORLD_6;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_7") == 0){
+		return MLV_KEYBOARD_WORLD_7;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_8") == 0){
+		return MLV_KEYBOARD_WORLD_8;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_9") == 0){
+		return MLV_KEYBOARD_WORLD_9;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_10") == 0){
+		return MLV_KEYBOARD_WORLD_10;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_11") == 0){
+		return MLV_KEYBOARD_WORLD_11;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_12") == 0){
+		return MLV_KEYBOARD_WORLD_12;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_13") == 0){
+		return MLV_KEYBOARD_WORLD_13;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_14") == 0){
+		return MLV_KEYBOARD_WORLD_14;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_15") == 0){
+		return MLV_KEYBOARD_WORLD_15;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_16") == 0){
+		return MLV_KEYBOARD_WORLD_16;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_17") == 0){
+		return MLV_KEYBOARD_WORLD_17;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_18") == 0){
+		return MLV_KEYBOARD_WORLD_18;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_19") == 0){
+		return MLV_KEYBOARD_WORLD_19;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_20") == 0){
+		return MLV_KEYBOARD_WORLD_20;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_21") == 0){
+		return MLV_KEYBOARD_WORLD_21;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_22") == 0){
+		return MLV_KEYBOARD_WORLD_22;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_23") == 0){
+		return MLV_KEYBOARD_WORLD_23;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_24") == 0){
+		return MLV_KEYBOARD_WORLD_24;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_25") == 0){
+		return MLV_KEYBOARD_WORLD_25;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_26") == 0){
+		return MLV_KEYBOARD_WORLD_26;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_27") == 0){
+		return MLV_KEYBOARD_WORLD_27;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_28") == 0){
+		return MLV_KEYBOARD_WORLD_28;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_29") == 0){
+		return MLV_KEYBOARD_WORLD_29;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_30") == 0){
+		return MLV_KEYBOARD_WORLD_30;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_31") == 0){
+		return MLV_KEYBOARD_WORLD_31;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_32") == 0){
+		return MLV_KEYBOARD_WORLD_32;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_33") == 0){
+		return MLV_KEYBOARD_WORLD_33;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_34") == 0){
+		return MLV_KEYBOARD_WORLD_34;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_35") == 0){
+		return MLV_KEYBOARD_WORLD_35;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_36") == 0){
+		return MLV_KEYBOARD_WORLD_36;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_37") == 0){
+		return MLV_KEYBOARD_WORLD_37;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_38") == 0){
+		return MLV_KEYBOARD_WORLD_38;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_39") == 0){
+		return MLV_KEYBOARD_WORLD_39;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_40") == 0){
+		return MLV_KEYBOARD_WORLD_40;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_41") == 0){
+		return MLV_KEYBOARD_WORLD_41;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_42") == 0){
+		return MLV_KEYBOARD_WORLD_42;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_43") == 0){
+		return MLV_KEYBOARD_WORLD_43;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_44") == 0){
+		return MLV_KEYBOARD_WORLD_44;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_45") == 0){
+		return MLV_KEYBOARD_WORLD_45;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_46") == 0){
+		return MLV_KEYBOARD_WORLD_46;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_47") == 0){
+		return MLV_KEYBOARD_WORLD_47;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_48") == 0){
+		return MLV_KEYBOARD_WORLD_48;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_49") == 0){
+		return MLV_KEYBOARD_WORLD_49;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_50") == 0){
+		return MLV_KEYBOARD_WORLD_50;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_51") == 0){
+		return MLV_KEYBOARD_WORLD_51;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_52") == 0){
+		return MLV_KEYBOARD_WORLD_52;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_53") == 0){
+		return MLV_KEYBOARD_WORLD_53;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_54") == 0){
+		return MLV_KEYBOARD_WORLD_54;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_55") == 0){
+		return MLV_KEYBOARD_WORLD_55;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_56") == 0){
+		return MLV_KEYBOARD_WORLD_56;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_57") == 0){
+		return MLV_KEYBOARD_WORLD_57;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_58") == 0){
+		return MLV_KEYBOARD_WORLD_58;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_59") == 0){
+		return MLV_KEYBOARD_WORLD_59;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_60") == 0){
+		return MLV_KEYBOARD_WORLD_60;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_61") == 0){
+		return MLV_KEYBOARD_WORLD_61;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_62") == 0){
+		return MLV_KEYBOARD_WORLD_62;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_63") == 0){
+		return MLV_KEYBOARD_WORLD_63;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_64") == 0){
+		return MLV_KEYBOARD_WORLD_64;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_65") == 0){
+		return MLV_KEYBOARD_WORLD_65;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_66") == 0){
+		return MLV_KEYBOARD_WORLD_66;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_67") == 0){
+		return MLV_KEYBOARD_WORLD_67;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_68") == 0){
+		return MLV_KEYBOARD_WORLD_68;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_69") == 0){
+		return MLV_KEYBOARD_WORLD_69;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_70") == 0){
+		return MLV_KEYBOARD_WORLD_70;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_71") == 0){
+		return MLV_KEYBOARD_WORLD_71;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_72") == 0){
+		return MLV_KEYBOARD_WORLD_72;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_73") == 0){
+		return MLV_KEYBOARD_WORLD_73;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_74") == 0){
+		return MLV_KEYBOARD_WORLD_74;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_75") == 0){
+		return MLV_KEYBOARD_WORLD_75;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_76") == 0){
+		return MLV_KEYBOARD_WORLD_76;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_77") == 0){
+		return MLV_KEYBOARD_WORLD_77;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_78") == 0){
+		return MLV_KEYBOARD_WORLD_78;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_79") == 0){
+		return MLV_KEYBOARD_WORLD_79;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_80") == 0){
+		return MLV_KEYBOARD_WORLD_80;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_81") == 0){
+		return MLV_KEYBOARD_WORLD_81;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_82") == 0){
+		return MLV_KEYBOARD_WORLD_82;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_83") == 0){
+		return MLV_KEYBOARD_WORLD_83;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_84") == 0){
+		return MLV_KEYBOARD_WORLD_84;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_85") == 0){
+		return MLV_KEYBOARD_WORLD_85;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_86") == 0){
+		return MLV_KEYBOARD_WORLD_86;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_87") == 0){
+		return MLV_KEYBOARD_WORLD_87;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_88") == 0){
+		return MLV_KEYBOARD_WORLD_88;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_89") == 0){
+		return MLV_KEYBOARD_WORLD_89;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_90") == 0){
+		return MLV_KEYBOARD_WORLD_90;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_91") == 0){
+		return MLV_KEYBOARD_WORLD_91;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_92") == 0){
+		return MLV_KEYBOARD_WORLD_92;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_93") == 0){
+		return MLV_KEYBOARD_WORLD_93;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_94") == 0){
+		return MLV_KEYBOARD_WORLD_94;
+	}
+
+	if(strcmp(key_string,"MLV_KEYBOARD_WORLD_95") == 0){
+		return MLV_KEYBOARD_WORLD_95;
+	}
+
 	if(strcmp(key_string,"MLV_KEYBOARD_KP0") == 0){
 		return MLV_KEYBOARD_KP0;
 	}
@@ -661,6 +1046,198 @@ const char* MLV_convert_keyboard_button_to_string( MLV_Keyboard_button key_code
 			return "MLV_KEYBOARD_z";
 		case MLV_KEYBOARD_DELETE :
 			return "MLV_KEYBOARD_DELETE";
+		case MLV_KEYBOARD_WORLD_0 :
+			return "MLV_KEYBOARD_WORLD_0";
+		case MLV_KEYBOARD_WORLD_1 :
+			return "MLV_KEYBOARD_WORLD_1";
+		case MLV_KEYBOARD_WORLD_2 :
+			return "MLV_KEYBOARD_WORLD_2";
+		case MLV_KEYBOARD_WORLD_3 :
+			return "MLV_KEYBOARD_WORLD_3";
+		case MLV_KEYBOARD_WORLD_4 :
+			return "MLV_KEYBOARD_WORLD_4";
+		case MLV_KEYBOARD_WORLD_5 :
+			return "MLV_KEYBOARD_WORLD_5";
+		case MLV_KEYBOARD_WORLD_6 :
+			return "MLV_KEYBOARD_WORLD_6";
+		case MLV_KEYBOARD_WORLD_7 :
+			return "MLV_KEYBOARD_WORLD_7";
+		case MLV_KEYBOARD_WORLD_8 :
+			return "MLV_KEYBOARD_WORLD_8";
+		case MLV_KEYBOARD_WORLD_9 :
+			return "MLV_KEYBOARD_WORLD_9";
+		case MLV_KEYBOARD_WORLD_10 :
+			return "MLV_KEYBOARD_WORLD_10";
+		case MLV_KEYBOARD_WORLD_11 :
+			return "MLV_KEYBOARD_WORLD_11";
+		case MLV_KEYBOARD_WORLD_12 :
+			return "MLV_KEYBOARD_WORLD_12";
+		case MLV_KEYBOARD_WORLD_13 :
+			return "MLV_KEYBOARD_WORLD_13";
+		case MLV_KEYBOARD_WORLD_14 :
+			return "MLV_KEYBOARD_WORLD_14";
+		case MLV_KEYBOARD_WORLD_15 :
+			return "MLV_KEYBOARD_WORLD_15";
+		case MLV_KEYBOARD_WORLD_16 :
+			return "MLV_KEYBOARD_WORLD_16";
+		case MLV_KEYBOARD_WORLD_17 :
+			return "MLV_KEYBOARD_WORLD_17";
+		case MLV_KEYBOARD_WORLD_18 :
+			return "MLV_KEYBOARD_WORLD_18";
+		case MLV_KEYBOARD_WORLD_19 :
+			return "MLV_KEYBOARD_WORLD_19";
+		case MLV_KEYBOARD_WORLD_20 :
+			return "MLV_KEYBOARD_WORLD_20";
+		case MLV_KEYBOARD_WORLD_21 :
+			return "MLV_KEYBOARD_WORLD_21";
+		case MLV_KEYBOARD_WORLD_22 :
+			return "MLV_KEYBOARD_WORLD_22";
+		case MLV_KEYBOARD_WORLD_23 :
+			return "MLV_KEYBOARD_WORLD_23";
+		case MLV_KEYBOARD_WORLD_24 :
+			return "MLV_KEYBOARD_WORLD_24";
+		case MLV_KEYBOARD_WORLD_25 :
+			return "MLV_KEYBOARD_WORLD_25";
+		case MLV_KEYBOARD_WORLD_26 :
+			return "MLV_KEYBOARD_WORLD_26";
+		case MLV_KEYBOARD_WORLD_27 :
+			return "MLV_KEYBOARD_WORLD_27";
+		case MLV_KEYBOARD_WORLD_28 :
+			return "MLV_KEYBOARD_WORLD_28";
+		case MLV_KEYBOARD_WORLD_29 :
+			return "MLV_KEYBOARD_WORLD_29";
+		case MLV_KEYBOARD_WORLD_30 :
+			return "MLV_KEYBOARD_WORLD_30";
+		case MLV_KEYBOARD_WORLD_31 :
+			return "MLV_KEYBOARD_WORLD_31";
+		case MLV_KEYBOARD_WORLD_32 :
+			return "MLV_KEYBOARD_WORLD_32";
+		case MLV_KEYBOARD_WORLD_33 :
+			return "MLV_KEYBOARD_WORLD_33";
+		case MLV_KEYBOARD_WORLD_34 :
+			return "MLV_KEYBOARD_WORLD_34";
+		case MLV_KEYBOARD_WORLD_35 :
+			return "MLV_KEYBOARD_WORLD_35";
+		case MLV_KEYBOARD_WORLD_36 :
+			return "MLV_KEYBOARD_WORLD_36";
+		case MLV_KEYBOARD_WORLD_37 :
+			return "MLV_KEYBOARD_WORLD_37";
+		case MLV_KEYBOARD_WORLD_38 :
+			return "MLV_KEYBOARD_WORLD_38";
+		case MLV_KEYBOARD_WORLD_39 :
+			return "MLV_KEYBOARD_WORLD_39";
+		case MLV_KEYBOARD_WORLD_40 :
+			return "MLV_KEYBOARD_WORLD_40";
+		case MLV_KEYBOARD_WORLD_41 :
+			return "MLV_KEYBOARD_WORLD_41";
+		case MLV_KEYBOARD_WORLD_42 :
+			return "MLV_KEYBOARD_WORLD_42";
+		case MLV_KEYBOARD_WORLD_43 :
+			return "MLV_KEYBOARD_WORLD_43";
+		case MLV_KEYBOARD_WORLD_44 :
+			return "MLV_KEYBOARD_WORLD_44";
+		case MLV_KEYBOARD_WORLD_45 :
+			return "MLV_KEYBOARD_WORLD_45";
+		case MLV_KEYBOARD_WORLD_46 :
+			return "MLV_KEYBOARD_WORLD_46";
+		case MLV_KEYBOARD_WORLD_47 :
+			return "MLV_KEYBOARD_WORLD_47";
+		case MLV_KEYBOARD_WORLD_48 :
+			return "MLV_KEYBOARD_WORLD_48";
+		case MLV_KEYBOARD_WORLD_49 :
+			return "MLV_KEYBOARD_WORLD_49";
+		case MLV_KEYBOARD_WORLD_50 :
+			return "MLV_KEYBOARD_WORLD_50";
+		case MLV_KEYBOARD_WORLD_51 :
+			return "MLV_KEYBOARD_WORLD_51";
+		case MLV_KEYBOARD_WORLD_52 :
+			return "MLV_KEYBOARD_WORLD_52";
+		case MLV_KEYBOARD_WORLD_53 :
+			return "MLV_KEYBOARD_WORLD_53";
+		case MLV_KEYBOARD_WORLD_54 :
+			return "MLV_KEYBOARD_WORLD_54";
+		case MLV_KEYBOARD_WORLD_55 :
+			return "MLV_KEYBOARD_WORLD_55";
+		case MLV_KEYBOARD_WORLD_56 :
+			return "MLV_KEYBOARD_WORLD_56";
+		case MLV_KEYBOARD_WORLD_57 :
+			return "MLV_KEYBOARD_WORLD_57";
+		case MLV_KEYBOARD_WORLD_58 :
+			return "MLV_KEYBOARD_WORLD_58";
+		case MLV_KEYBOARD_WORLD_59 :
+			return "MLV_KEYBOARD_WORLD_59";
+		case MLV_KEYBOARD_WORLD_60 :
+			return "MLV_KEYBOARD_WORLD_60";
+		case MLV_KEYBOARD_WORLD_61 :
+			return "MLV_KEYBOARD_WORLD_61";
+		case MLV_KEYBOARD_WORLD_62 :
+			return "MLV_KEYBOARD_WORLD_62";
+		case MLV_KEYBOARD_WORLD_63 :
+			return "MLV_KEYBOARD_WORLD_63";
+		case MLV_KEYBOARD_WORLD_64 :
+			return "MLV_KEYBOARD_WORLD_64";
+		case MLV_KEYBOARD_WORLD_65 :
+			return "MLV_KEYBOARD_WORLD_65";
+		case MLV_KEYBOARD_WORLD_66 :
+			return "MLV_KEYBOARD_WORLD_66";
+		case MLV_KEYBOARD_WORLD_67 :
+			return "MLV_KEYBOARD_WORLD_67";
+		case MLV_KEYBOARD_WORLD_68 :
+			return "MLV_KEYBOARD_WORLD_68";
+		case MLV_KEYBOARD_WORLD_69 :
+			return "MLV_KEYBOARD_WORLD_69";
+		case MLV_KEYBOARD_WORLD_70 :
+			return "MLV_KEYBOARD_WORLD_70";
+		case MLV_KEYBOARD_WORLD_71 :
+			return "MLV_KEYBOARD_WORLD_71";
+		case MLV_KEYBOARD_WORLD_72 :
+			return "MLV_KEYBOARD_WORLD_72";
+		case MLV_KEYBOARD_WORLD_73 :
+			return "MLV_KEYBOARD_WORLD_73";
+		case MLV_KEYBOARD_WORLD_74 :
+			return "MLV_KEYBOARD_WORLD_74";
+		case MLV_KEYBOARD_WORLD_75 :
+			return "MLV_KEYBOARD_WORLD_75";
+		case MLV_KEYBOARD_WORLD_76 :
+			return "MLV_KEYBOARD_WORLD_76";
+		case MLV_KEYBOARD_WORLD_77 :
+			return "MLV_KEYBOARD_WORLD_77";
+		case MLV_KEYBOARD_WORLD_78 :
+			return "MLV_KEYBOARD_WORLD_78";
+		case MLV_KEYBOARD_WORLD_79 :
+			return "MLV_KEYBOARD_WORLD_79";
+		case MLV_KEYBOARD_WORLD_80 :
+			return "MLV_KEYBOARD_WORLD_80";
+		case MLV_KEYBOARD_WORLD_81 :
+			return "MLV_KEYBOARD_WORLD_81";
+		case MLV_KEYBOARD_WORLD_82 :
+			return "MLV_KEYBOARD_WORLD_82";
+		case MLV_KEYBOARD_WORLD_83 :
+			return "MLV_KEYBOARD_WORLD_83";
+		case MLV_KEYBOARD_WORLD_84 :
+			return "MLV_KEYBOARD_WORLD_84";
+		case MLV_KEYBOARD_WORLD_85 :
+			return "MLV_KEYBOARD_WORLD_85";
+		case MLV_KEYBOARD_WORLD_86 :
+			return "MLV_KEYBOARD_WORLD_86";
+		case MLV_KEYBOARD_WORLD_87 :
+			return "MLV_KEYBOARD_WORLD_87";
+		case MLV_KEYBOARD_WORLD_88 :
+			return "MLV_KEYBOARD_WORLD_88";
+		case MLV_KEYBOARD_WORLD_89 :
+			return "MLV_KEYBOARD_WORLD_89";
+		case MLV_KEYBOARD_WORLD_90 :
+			return "MLV_KEYBOARD_WORLD_90";
+		case MLV_KEYBOARD_WORLD_91 :
+			return "MLV_KEYBOARD_WORLD_91";
+		case MLV_KEYBOARD_WORLD_92 :
+			return "MLV_KEYBOARD_WORLD_92";
+		case MLV_KEYBOARD_WORLD_93 :
+			return "MLV_KEYBOARD_WORLD_93";
+		case MLV_KEYBOARD_WORLD_94 :
+			return "MLV_KEYBOARD_WORLD_94";
+		case MLV_KEYBOARD_WORLD_95 :
+			return "MLV_KEYBOARD_WORLD_95";
 		case MLV_KEYBOARD_KP0 :
 			return "MLV_KEYBOARD_KP0";
 		case MLV_KEYBOARD_KP1 :
@@ -796,82 +1373,208 @@ const char* MLV_convert_keyboard_button_to_string( MLV_Keyboard_button key_code
 	}
 }
 
-MLV_Keyboard_modifier MLV_convert_string_to_keyboard_mod( const char* keymod_string ){
-	if(strcmp(keymod_string,"MLV_KEYBOARD_KMOD_NONE") == 0){
-		return MLV_KEYBOARD_KMOD_NONE;
+char* MLV_convert_keyboard_mod_to_string( MLV_Keyboard_modifier keymod_code ){
+	int text_size = 0;
+	char* text;
+	char* result;
+	int nb = 0;
+	
+	if( keymod_code == MLV_KEYBOARD_KMOD_NONE ){
+		text = "MLV_KEYBOARD_KMOD_NONE";
+		result = MLV_MALLOC( strlen(text)+1, char );
+		sprintf( result, "%s", text );
+		return result;
 	}
-	if(strcmp(keymod_string,"MLV_KEYBOARD_KMOD_LSHIFT")==0){
-		return MLV_KEYBOARD_KMOD_LSHIFT;
-	}
-	if(strcmp(keymod_string,"MLV_KEYBOARD_KMOD_RSHIFT")==0){
-		return MLV_KEYBOARD_KMOD_RSHIFT;
-	}
-	if(strcmp(keymod_string,"MLV_KEYBOARD_KMOD_LCTRL")==0){
-		return MLV_KEYBOARD_KMOD_LCTRL;
-	}
-	if(strcmp(keymod_string,"MLV_KEYBOARD_KMOD_RCTRL")==0){
-		return MLV_KEYBOARD_KMOD_RCTRL;
-	}
-	if(strcmp(keymod_string,"MLV_KEYBOARD_KMOD_LALT")==0){
-		return MLV_KEYBOARD_KMOD_LALT;
-	}
-	if(strcmp(keymod_string,"MLV_KEYBOARD_KMOD_RALT")==0){
-		return MLV_KEYBOARD_KMOD_RALT;
-	}
-	if(strcmp(keymod_string,"MLV_KEYBOARD_KMOD_LMETA")==0){
-		return MLV_KEYBOARD_KMOD_LMETA;
-	}
-	if(strcmp(keymod_string,"MLV_KEYBOARD_KMOD_RMETA")==0){
-		return MLV_KEYBOARD_KMOD_RMETA;
-	}
-	if(strcmp(keymod_string,"MLV_KEYBOARD_KMOD_NUM")==0){
-		return MLV_KEYBOARD_KMOD_NUM;
-	}
-	if(strcmp(keymod_string,"MLV_KEYBOARD_KMOD_CAPS")==0){
-		return MLV_KEYBOARD_KMOD_CAPS;
-	}
-	if(strcmp(keymod_string,"MLV_KEYBOARD_KMOD_MODE")==0){
-		return MLV_KEYBOARD_KMOD_MODE;
-	}
-	if(strcmp(keymod_string,"MLV_KEYBOARD_KMOD_RESERVED")==0){
-		return MLV_KEYBOARD_KMOD_RESERVED;
-	}
-	ERROR("unexpected mod");
-	return 0;
-}
 
-const char* MLV_convert_keyboard_mod_to_string( MLV_Keyboard_modifier keymod_code ){
-	switch( keymod_code ){
-		case MLV_KEYBOARD_KMOD_NONE:
-			return "MLV_KEYBOARD_KMOD_NONE";
-		case MLV_KEYBOARD_KMOD_LSHIFT:
-			return "MLV_KEYBOARD_KMOD_LSHIFT";
-		case MLV_KEYBOARD_KMOD_RSHIFT:
-			return "MLV_KEYBOARD_KMOD_RSHIFT";
-		case MLV_KEYBOARD_KMOD_LCTRL:
-			return "MLV_KEYBOARD_KMOD_LCTRL";
-		case MLV_KEYBOARD_KMOD_RCTRL:
-			return "MLV_KEYBOARD_KMOD_RCTRL";
-		case MLV_KEYBOARD_KMOD_LALT:
-			return "MLV_KEYBOARD_KMOD_LALT";
-		case MLV_KEYBOARD_KMOD_RALT:
-			return "MLV_KEYBOARD_KMOD_RALT";
-		case MLV_KEYBOARD_KMOD_LMETA:
-			return "MLV_KEYBOARD_KMOD_LMETA";
-		case MLV_KEYBOARD_KMOD_RMETA:
-			return "MLV_KEYBOARD_KMOD_RMETA";
-		case MLV_KEYBOARD_KMOD_NUM:
-			return "MLV_KEYBOARD_KMOD_NUM";
-		case MLV_KEYBOARD_KMOD_CAPS:
-			return "MLV_KEYBOARD_KMOD_CAPS";
-		case MLV_KEYBOARD_KMOD_MODE:
-			return "MLV_KEYBOARD_KMOD_MODE";
-		case MLV_KEYBOARD_KMOD_RESERVED:
-			return "MLV_KEYBOARD_KMOD_RESERVED";
-		default:
-			ERROR("Unexpected keymod_code");
+	if( keymod_code & MLV_KEYBOARD_KMOD_NONE ){
+		if( nb>0 ){
+			text_size += 3;
+		}
+		text_size += strlen( "MLV_KEYBOARD_KMOD_NONE" );
+		nb += 1;
 	}
-	return NULL;
+	if( keymod_code & MLV_KEYBOARD_KMOD_LSHIFT ){
+		if( nb>0 ){
+			text_size += 3;
+		}
+		text_size += strlen( "MLV_KEYBOARD_KMOD_LSHIFT" );
+		nb += 1;
+	}
+	if( keymod_code & MLV_KEYBOARD_KMOD_RSHIFT ){
+		if( nb>0 ){
+			text_size += 3;
+		}
+		text_size += strlen( "MLV_KEYBOARD_KMOD_RSHIFT" );
+		nb += 1;
+	}
+	if( keymod_code & MLV_KEYBOARD_KMOD_LCTRL ){
+		if( nb>0 ){
+			text_size += 3;
+		}
+		text_size += strlen( "MLV_KEYBOARD_KMOD_LCTRL" );
+		nb += 1;
+	}
+	if( keymod_code & MLV_KEYBOARD_KMOD_RCTRL ){
+		if( nb>0 ){
+			text_size += 3;
+		}
+		text_size += strlen( "MLV_KEYBOARD_KMOD_RCTRL" );
+		nb += 1;
+	}
+	if( keymod_code & MLV_KEYBOARD_KMOD_LALT ){
+		if( nb>0 ){
+			text_size += 3;
+		}
+		text_size += strlen( "MLV_KEYBOARD_KMOD_LALT" );
+		nb += 1;
+	}
+	if( keymod_code & MLV_KEYBOARD_KMOD_RALT ){
+		if( nb>0 ){
+			text_size += 3;
+		}
+		text_size += strlen( "MLV_KEYBOARD_KMOD_RALT" );
+		nb += 1;
+	}
+	if( keymod_code & MLV_KEYBOARD_KMOD_LMETA ){
+		if( nb>0 ){
+			text_size += 3;
+		}
+		text_size += strlen( "MLV_KEYBOARD_KMOD_LMETA" );
+		nb += 1;
+	}
+	if( keymod_code & MLV_KEYBOARD_KMOD_RMETA ){
+		if( nb>0 ){
+			text_size += 3;
+		}
+		text_size += strlen( "MLV_KEYBOARD_KMOD_RMETA" );
+		nb += 1;
+	}
+	if( keymod_code & MLV_KEYBOARD_KMOD_NUM ){
+		if( nb>0 ){
+			text_size += 3;
+		}
+		text_size += strlen( "MLV_KEYBOARD_KMOD_NUM" );
+		nb += 1;
+	}
+	if( keymod_code & MLV_KEYBOARD_KMOD_CAPS ){
+		if( nb>0 ){
+			text_size += 3;
+		}
+		text_size += strlen( "MLV_KEYBOARD_KMOD_CAPS" );
+		nb += 1;
+	}
+	if( keymod_code & MLV_KEYBOARD_KMOD_MODE ){
+		if( nb>0 ){
+			text_size += 3;
+		}
+		text_size += strlen( "MLV_KEYBOARD_KMOD_MODE" );
+		nb += 1;
+	}
+	if( keymod_code & MLV_KEYBOARD_KMOD_RESERVED ){
+		if( nb>0 ){
+			text_size += 3;
+		}
+		text_size += strlen( "MLV_KEYBOARD_KMOD_RESERVED" );
+		nb += 1;
+	}
+
+	text = MLV_MALLOC( text_size+1, char );
+	text[text_size] = '\0';
+	result = text;
+
+	nb = 0;
+	if( keymod_code & MLV_KEYBOARD_KMOD_NONE ){
+		if( nb>0 ){
+			text += sprintf( text, " | " );
+		}
+		text += sprintf( text, "MLV_KEYBOARD_KMOD_NONE" );
+		nb += 1;
+	}
+	if( keymod_code & MLV_KEYBOARD_KMOD_LSHIFT ){
+		if( nb>0 ){
+			text += sprintf( text, " | " );
+		}
+		text += sprintf( text, "MLV_KEYBOARD_KMOD_LSHIFT" );
+		nb += 1;
+	}
+	if( keymod_code & MLV_KEYBOARD_KMOD_RSHIFT ){
+		if( nb>0 ){
+			text += sprintf( text, " | " );
+		}
+		text += sprintf( text, "MLV_KEYBOARD_KMOD_RSHIFT" );
+		nb += 1;
+	}
+	if( keymod_code & MLV_KEYBOARD_KMOD_LCTRL ){
+		if( nb>0 ){
+			text += sprintf( text, " | " );
+		}
+		text += sprintf( text, "MLV_KEYBOARD_KMOD_LCTRL" );
+		nb += 1;
+	}
+	if( keymod_code & MLV_KEYBOARD_KMOD_RCTRL ){
+		if( nb>0 ){
+			text += sprintf( text, " | " );
+		}
+		text += sprintf( text, "MLV_KEYBOARD_KMOD_RCTRL" );
+		nb += 1;
+	}
+	if( keymod_code & MLV_KEYBOARD_KMOD_LALT ){
+		if( nb>0 ){
+			text += sprintf( text, " | " );
+		}
+		text += sprintf( text, "MLV_KEYBOARD_KMOD_LALT" );
+		nb += 1;
+	}
+	if( keymod_code & MLV_KEYBOARD_KMOD_RALT ){
+		if( nb>0 ){
+			text += sprintf( text, " | " );
+		}
+		text += sprintf( text, "MLV_KEYBOARD_KMOD_RALT" );
+		nb += 1;
+	}
+	if( keymod_code & MLV_KEYBOARD_KMOD_LMETA ){
+		if( nb>0 ){
+			text += sprintf( text, " | " );
+		}
+		text += sprintf( text, "MLV_KEYBOARD_KMOD_LMETA" );
+		nb += 1;
+	}
+	if( keymod_code & MLV_KEYBOARD_KMOD_RMETA ){
+		if( nb>0 ){
+			text += sprintf( text, " | " );
+		}
+		text += sprintf( text, "MLV_KEYBOARD_KMOD_RMETA" );
+		nb += 1;
+	}
+	if( keymod_code & MLV_KEYBOARD_KMOD_NUM ){
+		if( nb>0 ){
+			text += sprintf( text, " | " );
+		}
+		text += sprintf( text, "MLV_KEYBOARD_KMOD_NUM" );
+		nb += 1;
+	}
+	if( keymod_code & MLV_KEYBOARD_KMOD_CAPS ){
+		if( nb>0 ){
+			text += sprintf( text, " | " );
+		}
+		text += sprintf( text, "MLV_KEYBOARD_KMOD_CAPS" );
+		nb += 1;
+	}
+	if( keymod_code & MLV_KEYBOARD_KMOD_MODE ){
+		if( nb>0 ){
+			text += sprintf( text, " | " );
+		}
+		text += sprintf( text, "MLV_KEYBOARD_KMOD_MODE" );
+		nb += 1;
+	}
+	if( keymod_code & MLV_KEYBOARD_KMOD_RESERVED ){
+		if( nb>0 ){
+			text += sprintf( text, " | " );
+		}
+		text += sprintf( text, "MLV_KEYBOARD_KMOD_RESERVED" );
+		nb += 1;
+	}
+	return result;
 }
 
 
